#!/bin/sh

ib0="10.10.2.82"
devs=$(egrep "MR9361-8i" /sys/block/sd?/device/model | awk -F '/' '{print $4}')
dev_num=$(egrep "MR9361-8i" /sys/block/sd?/device/model | wc -l)
tgt_num=12
blk_num=`expr $dev_num / $tgt_num`
dev_cnt=1
blk_cnt=1

## Set SSD alignment
for dev in $devs
do
        parted -a optimal -s /dev/$dev mklabel gpt mkpart primary 512s 100%; parted -s /dev/$dev unit s print
done
sleep 3

## Create Target LUN (Using targetcli)
# clear target configure
targetcli clearconfig confirm=true
sleep 3

# create backstores
uuids=$(ls /dev/disk/by-path/pci-0000\:0[1-3]:00.0-scsi-0:2:?:0-part1)
for uuid in $uuids;
do
	echo "/backstores/block create iser_disk$dev_cnt $uuid" | targetcli
	dev_cnt=`expr $dev_cnt + 1`
done
sleep 3

tgts=$(ls /sys/kernel/config/target/iscsi/ | grep gluesys)
for tgt in $tgts;
do
	echo "/iscsi delete $tgt" | targetcli
done

for ((i=1; i<=tgt_num; i++));
do
	# create iqn
	echo "/iscsi create iqn.2019-08.gluesys.com:iser$i" | targetcli

	# add blocks to iqn
	for ((k=1; k<=blk_num; k++));
	do
		echo "/iscsi/iqn.2019-08.gluesys.com:iser$i/tpg1/luns create /backstores/block/iser_disk$blk_cnt" | targetcli
		blk_cnt=`expr $blk_cnt + 1`
	done
	
	# delete the IP addresse 0.0.0.0 assigned automatically
	ls /sys/kernel/config/target/iscsi/iqn.2019-08.gluesys.com:iser$i/tpgt_1/np/0.0.0.0:3260 > /dev/null 2>&1
	if [ 0 -eq $? ];
	then
		echo "/iscsi/iqn.2019-08.gluesys.com:iser$i/tpg1/portals delete 0.0.0.0 3260" | targetcli
	fi

	# Asssign IP addresses to iqn and ISER
	echo "/iscsi/iqn.2019-08.gluesys.com:iser$i/tpg1/portals create $ib0" | targetcli
	echo "/iscsi/iqn.2019-08.gluesys.com:iser$i/tpg1/portals/$ib0:3260 enable_iser boolean=true" | targetcli

	# change the configure of each iqn
	echo "/iscsi/iqn.2019-08.gluesys.com:iser$i/tpg1 set attribute authentication=0 demo_mode_write_protect=0 generate_node_acls=1 cache_dynamic_acls=1" | targetcli
done
sleep 3

# restart target systemd
systemctl restart target

sleep 3

## Set the storage kernel parameters
$PWD/set_storage_kernel_parameters.sh
